#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['tomli_w']

package_data = \
{'': ['*']}

setup(name='tomli_w',
      version='0.3.0',
      description="A lil' TOML writer",
      author=None,
      author_email='Taneli Hukkinen <hukkin@users.noreply.github.com>',
      url=None,
      packages=packages,
      package_data=package_data,
      python_requires='>=3.6',
     )
